# helper-read [![NPM version](https://badge.fury.io/js/helper-read.svg)](http://badge.fury.io/js/helper-read)

> Template helper for reading from the file system. Includes both async and sync versions.

## Install

Install with [npm](https://www.npmjs.com/)

```bash
npm i helper-read --save
```

## Usage

```js
var read = require('helper-read');
```

**Usage with [lodash](https://lodash.com/)**

```js
var ctx = {read: read.sync};
_.template('<%= read("fixtures/a.txt") %>')(ctx);
//=> 'AAA'
_.template('<%= read("fixtures/b.txt") %>')(ctx);
//=> 'BBB'
```

**Usage with [Template](https://github.com/jonschlinkert/template)**

```js
var read = require('helper-read');
var Template = require('template');
var template = new Template();

/**
 * Register an engine
 */

template.engine('foo', require('engine-lodash'));

/**
 * Register the helper
 */

template.asyncHelper('read', read);

/**
 * Add some templates
 */

template.page('abc.foo', '<%= read("fixtures/a.txt") %>');
template.page('xyz.foo', '<%= read("fixtures/b.txt") %>');

/**
 * Render the templates
 */

template.render('abc.foo', function (err, contents) {
  if (err) console.log(err);
  console.log(contents);
  //=> 'AAA'
});

template.render('xyz.foo', function (err, contents) {
  if (err) console.log(err);
  console.log(contents);
  //=> 'BBB'
});
```

## Related projects

* [assemble](http://assemble.io): Static site generator for Grunt.js, Yeoman and Node.js. Used by Zurb Foundation, Zurb Ink, H5BP/Effeckt,… [more](http://assemble.io)
* [template](https://github.com/jonschlinkert/template): Render templates using any engine. Supports, layouts, pages, partials and custom template types. Use template… [more](https://github.com/jonschlinkert/template)
* [template-helpers](https://github.com/jonschlinkert/template-helpers): Generic JavaScript helpers that can be used with any template engine. Handlebars, Lo-Dash, Underscore, or… [more](https://github.com/jonschlinkert/template-helpers)
* [verb](https://github.com/assemble/verb): Documentation generator for GitHub projects. Extremely powerful, easy to use, can generate anything from API… [more](https://github.com/assemble/verb)

## Running tests

Install dev dependencies:

```bash
npm i -d && npm test
```

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/helper-read/issues/new)

## Author

**Jon Schlinkert**

+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright (c) 2015 Jon Schlinkert
Released under the MIT license.

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on May 11, 2015._